@@ -15,6 +15,7 @@ class QKeyEvent;
 //class PIRTabWidget;
 
 class PIRSelectKeysetForm;
+class PIRPowerSearchForm;
 class PIRSelectDeviceForm;
 class PIRPreferencesForm;
 class PIRDocumentationForm;
@@ -137,6 +138,9 @@ public:
   void switchToTab(
     int tabNumber);
 
+  void switchToNextTab();
+  void switchToPrevTab();
+
   void handleKeypress(
     char key);
 
@@ -166,6 +170,7 @@ public slots:
 
 private slots:
   void on_actionSelectKeyset_triggered();
+  void on_actionAutomatic_Keyset_Search_triggered();
   void on_actionBrowse_Device_List_triggered();
   void on_actionPreferences_triggered();
   void on_actionAbout_triggered();
@@ -188,6 +193,7 @@ private:
 //  PIRTabWidget *myTabWidget;
 
   PIRSelectKeysetForm *selectKeysetForm;
+  PIRPowerSearchForm *powerSearchForm;
   PIRSelectDeviceForm *selectDeviceForm;
   PIRPreferencesForm *preferencesForm;
   PIRDocumentationForm *documentationForm;
