@@ -11,6 +11,7 @@
 #include "keysets/adb.h"
 #include "keysets/admiral.h"
 #include "keysets/aiwa.h"
+#include "keysets/alpine.h"
 #include "keysets/anitech.h"
 #include "keysets/aoc.h"
 #include "keysets/apple.h"
@@ -61,6 +62,7 @@
 #include "keysets/huawei.h"
 #include "keysets/humax.h"
 #include "keysets/hyundai.h"
+#include "keysets/ilo.h"
 #include "keysets/irobot.h"
 #include "keysets/jvc.h"
 #include "keysets/kaon.h"
@@ -103,12 +105,14 @@
 #include "keysets/roku.h"
 #include "keysets/saba.h"
 #include "keysets/sagem.h"
+#include "keysets/sagemcom.h"
 #include "keysets/samsung.h"
 #include "keysets/sanyo.h"
 #include "keysets/sharp.h"
 #include "keysets/sinotec.h"
 #include "keysets/sky.h"
 #include "keysets/sony.h"
+#include "keysets/starhub.h"
 #include "keysets/starsat.h"
 #include "keysets/strong.h"
 #include "keysets/sylvania.h"
@@ -186,6 +190,8 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new AiwaCarStereo1(++counter));
   setupKeyset(new AiwaDVD1(++counter));
 
+  setupKeyset(new AlpineAudio1(++counter));
+
   setupKeyset(new AnitechTV1(++counter));
   setupKeyset(new AnitechVCR1(++counter));
 
@@ -417,6 +423,10 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new HyundaiAudio1(++counter));
   setupKeyset(new HyundaiTV1(++counter));
 
+  setupKeyset(new ILOTV1(++counter));
+  setupKeyset(new ILOTV2(++counter));
+  setupKeyset(new ILOTV3(++counter));
+
   setupKeyset(new IRobotRoomba1(++counter));
 
   setupKeyset(new JVCSat1(++counter));
@@ -674,6 +684,9 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new SagemTVBox1(++counter));
   setupKeyset(new SagemTVBox1a(++counter));
 
+  setupKeyset(new SagemcomSTB1(++counter));
+  setupKeyset(new SagemcomSTB2(++counter));
+
   setupKeyset(new SamsungTV1(++counter));
   setupKeyset(new SamsungTV1a(++counter));
   setupKeyset(new SamsungTV1b(++counter));
@@ -747,12 +760,16 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new SonyProjector1(++counter));
   setupKeyset(new SonyProjector1a(++counter));
 
+  setupKeyset(new StarhubSTB1(++counter));
+  setupKeyset(new StarhubSTB1a(++counter));
+
   setupKeyset(new StarsatSat1(++counter));
 
   setupKeyset(new StrongSat1(++counter));
   setupKeyset(new StrongSat2(++counter));
   setupKeyset(new StrongSat3(++counter));
   setupKeyset(new StrongSat4(++counter));
+  setupKeyset(new StrongDVBT1(++counter));
 
   setupKeyset(new SylvaniaTV1(++counter));
 
@@ -761,6 +778,9 @@ PIRKeysetManager::PIRKeysetManager()
   setupKeyset(new TechnicsAudio2(++counter));
   setupKeyset(new TechnicsAudio3(++counter));
   setupKeyset(new TechnicsAudio3a(++counter));
+  setupKeyset(new TechnicsReceiver1(++counter));
+  setupKeyset(new TechnicsReceiver1a(++counter));
+  setupKeyset(new TechnicsCD1(++counter));
   setupKeyset(new TechnicsDVD1(++counter));
 
   setupKeyset(new TechnisatSTB1(++counter));
