@@ -10,6 +10,7 @@ enum PIRMakeName{
   ADB_Make,
   Admiral_Make,
   Aiwa_Make,
+  Alpine_Make,
   Anitech_Make,
   AOC_Make,
   Apple_Make,
@@ -60,6 +61,7 @@ enum PIRMakeName{
   Huawei_Make,
   Humax_Make,
   Hyundai_Make,
+  ILO_Make,
   IRobot_Make,
   JVC_Make,
   Kaon_Make,
@@ -102,12 +104,14 @@ enum PIRMakeName{
   Roku_Make,
   Saba_Make,
   Sagem_Make,
+  Sagemcom_Make,
   Samsung_Make,
   Sanyo_Make,
   Sharp_Make,
   Sinotec_Make,
   Sky_Make,
   Sony_Make,
+  Starhub_Make,
   Starsat_Make,
   Strong_Make,
   Sylvania_Make,
