@@ -17,7 +17,7 @@
 #include "forms/pirroombaform.h"
 #include "forms/piruserform.h"
 #include "forms/pirmacroform.h"
-#include "forms/pirpowersearchform.h"
+//#include "forms/pirpowersearchform.h"
 #include "forms/piradvancedform.h"
 
 #include "mainwindow.h"
@@ -49,7 +49,7 @@ PIRPanelManager::PIRPanelManager(
     roombaForm(0),
     userForm(0),
     macroForm(0),
-    powerSearchForm(0),
+//    powerSearchForm(0),
     advancedForm(0),
     altMainPanelFlag(false),
     currentTabsName(Universal_Tabs),
@@ -119,9 +119,9 @@ PIRPanelManager::PIRPanelManager(
   shortPanelNames[Macro_Panel] = "Edit Macro Contents";
   longPanelNames[Macro_Panel] =
     "Edit Macros Panel - create, delete, edit, and manage macros";
-  shortPanelNames[PowerSearch_Panel] = "Keyset Search";
-  longPanelNames[PowerSearch_Panel] =
-    "Keyset Search Panel - execute power button in each keyset";
+//  shortPanelNames[PowerSearch_Panel] = "Keyset Search";
+//  longPanelNames[PowerSearch_Panel] =
+//    "Keyset Search Panel - execute power button in each keyset";
   shortPanelNames[Advanced_Panel] = "Advanced Settings";
   longPanelNames[Advanced_Panel] =
     "Advanced Settings - allows adjustment of protocol settings";
@@ -177,8 +177,8 @@ PIRPanelManager::PIRPanelManager(
   macroForm = new PIRMacroForm(mainWindow);
   panels[Macro_Panel] = macroForm;
 
-  powerSearchForm = new PIRPowerSearchForm(mainWindow);
-  panels[PowerSearch_Panel] = powerSearchForm;
+//  powerSearchForm = new PIRPowerSearchForm(mainWindow);
+//  panels[PowerSearch_Panel] = powerSearchForm;
 
   advancedForm = new PIRAdvancedForm();
   panels[Advanced_Panel] = advancedForm;
@@ -251,9 +251,9 @@ PIRPanelManager::PIRPanelManager(
   tabLists[Macro_Tabs] = pset;
 
   // The Power Search collection:
-  pset.clear();
-  pset.push_back(PowerSearch_Panel);
-  tabLists[PowerSearch_Tabs] = pset;
+//  pset.clear();
+//  pset.push_back(PowerSearch_Panel);
+//  tabLists[PowerSearch_Tabs] = pset;
 
   // The Advanced Settings collection:
   pset.clear();
@@ -340,7 +340,7 @@ void PIRPanelManager::commonEnableButtons(
   roombaForm->enableButtons(keyset, id);
 
   // Also, set the label in the power search form:
-  powerSearchForm->setKeysetName(mainWindow->getCurrentFullName());
+//  powerSearchForm->setKeysetName(mainWindow->getCurrentFullName());
 
   // Set up the advanced parameters:
   advancedForm->setupForm(keyset, id);
