@@ -20,7 +20,7 @@ enum PIRPanelName
   Roomba_Panel,
   User_Panel,
   Macro_Panel,
-  PowerSearch_Panel,
+//  PowerSearch_Panel,
   Advanced_Panel,
   Last_Panel_Marker // Used when traversing this enumeration.
 };
@@ -39,7 +39,7 @@ enum PIRTabBarName
   Camera_Tabs,
   Roomba_Tabs,
   Macro_Tabs,
-  PowerSearch_Tabs,
+//  PowerSearch_Tabs,
   Advanced_Tabs,
   Last_Tabs_Marker
 };
